from distutils.core import setup
setup(
  name = 'realbrowserlocusts',
  packages = ['realbrowserlocusts'],
  version = '0.2',
  description = 'Minimal set of real browser (Firefox, Chrome and PhantomJS) locusts to be used in conjuntion with locust.io',
  author = 'Nick Bocuart',
  author_email = 'nboucart@gmail.com',
  url = 'https://github.com/nickboucart/realbrowserlocusts',
  download_url = 'https://github.com/nickboucart/realbrowserlocusts/tarball/0.2',
  keywords = ['testing', 'locust'],
  classifiers = [],
)
